'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.shouldRemoveWidgetToUserProfile = exports.addWidgetConfigurationToUserProfile = exports.invalidAddWidgetConfigurationToUserProfile = exports.removeOnBoarding = exports.resetRealTimeInviteUserInformation = exports.shouldShowEmailIsAlreadyTaken = exports.shouldCloseInviteUserDialog = exports.shouldOpenInviteUserDialog = exports.shouldFindIfEmailExist = exports.shouldFindIfUserExist = exports.shouldUnBlock = exports.shouldBlock = exports.shouldDemote = exports.shouldPromote = exports.shouldResendInvitation = exports.shouldInviteUser = exports.fetchAllUsers = undefined;
exports.fetchPotentialUsersIfNeeded = fetchPotentialUsersIfNeeded;
exports.shouldFetchCurrentUser = shouldFetchCurrentUser;
exports.checkIfEmailExistAndSendInvitation = checkIfEmailExistAndSendInvitation;
exports.shouldFetchInvitations = shouldFetchInvitations;
exports.shouldRemoveInvitation = shouldRemoveInvitation;
exports.receiveRealTimePromoteInformation = receiveRealTimePromoteInformation;
exports.resetPromoteUserInformation = resetPromoteUserInformation;
exports.receiveRealTimeDemoteInformation = receiveRealTimeDemoteInformation;
exports.resetDemoteUserInformation = resetDemoteUserInformation;
exports.shouldChangePassword = shouldChangePassword;
exports.receiveRealTimeInvitedUserInformation = receiveRealTimeInvitedUserInformation;

var _constants = require('../constants');

var _constants2 = _interopRequireDefault(_constants);

var _data = require('../data');

var _actions = require('cluedin-core/actions');

var _location = require('cluedin-core/location');

var _reducers = require('../reducers');

var _jsCookie = require('js-cookie');

var _jsCookie2 = _interopRequireDefault(_jsCookie);

var _logger = require('cluedin-core/logger');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function shouldFetchAllUsers(state) {
  if (state[_reducers.storeName].isFetching) {
    return false;
  }

  return !(state[_reducers.storeName].allUsers && state[_reducers.storeName].allUsers.length > 0);
}

var fetchAllUsers = exports.fetchAllUsers = function fetchAllUsers() {
  return function (dispatch, getState) {
    if (shouldFetchAllUsers(getState())) {
      dispatch(requestAllUsers());

      return (0, _data.getAllUsers)().then(function (users) {
        return dispatch(receiveAllUsers(users));
      }).catch((0, _actions.unauthorized)(dispatch, invalidAllUsers));
    }
  };
};

var requestAllUsers = function requestAllUsers() {
  return {
    type: _constants2.default.REQUEST_ALL_USERS
  };
};

var receiveAllUsers = function receiveAllUsers(users) {
  return {
    type: _constants2.default.RECEIVE_ALL_USERS,
    data: {
      users: users
    }
  };
};

var invalidAllUsers = function invalidAllUsers() {
  return {
    type: _constants2.default.INVALID_ALL_USERS
  };
};

var requestInviteUser = function requestInviteUser(invitation) {
  return {
    type: _constants2.default.REQUEST_INVITE_USER,
    data: {
      invitation: invitation
    }
  };
};

var receiveInviteUser = function receiveInviteUser(invitation) {
  return {
    type: _constants2.default.RECEIVE_INVITE_USER,
    data: {
      invitation: invitation
    }
  };
};

var invalidInviteUser = function invalidInviteUser() {
  return {
    type: _constants2.default.INVALID_INVITE_USER
  };
};

var shouldInviteUser = exports.shouldInviteUser = function shouldInviteUser(invitation) {
  return function (dispatch) {
    dispatch(requestInviteUser(invitation));

    return (0, _data.inviteUser)(invitation).then(function (resp) {
      dispatch(receiveRealTimeInvitedUserInformation(invitation));

      setTimeout(function () {
        dispatch(resetRealTimeInviteUserInformation(invitation));
      }, 5000);

      // save invit for test purp
      window && (window.testIntegrationInAppInvit = resp.body);

      return dispatch(receiveInviteUser(invitation, resp.body));
    }).catch((0, _actions.unauthorized)(dispatch, invalidInviteUser));
  };
};

var requestResendInvitation = function requestResendInvitation(invitation) {
  return {
    type: _constants2.default.REQUEST_RESEND_INVITATION,
    data: {
      invitation: invitation
    }
  };
};

var receiveResendInvitation = function receiveResendInvitation(invitation) {
  return {
    type: _constants2.default.RECEIVE_RESEND_INVITATION,
    data: {
      invitation: invitation
    }
  };
};

var invalidResendInvitation = function invalidResendInvitation(invitation) {
  return {
    type: _constants2.default.INVALID_RESEND_INVITATION,
    data: { invitation: invitation }
  };
};

var shouldResendInvitation = exports.shouldResendInvitation = function shouldResendInvitation(invitation) {
  return function (dispatch) {
    dispatch(requestResendInvitation(invitation));

    return (0, _data.resendInvitation)(invitation).then(function (resp) {
      return dispatch(receiveResendInvitation(invitation, resp.body));
    }).catch(function (err) {
      (0, _logger.logException)(err);
      dispatch(invalidResendInvitation(invitation));
    });
  };
};

var requestPromote = function requestPromote(userName) {
  return {
    type: _constants2.default.REQUEST_PROMOTE_USER,
    data: {
      userName: userName
    }
  };
};

var receivePromote = function receivePromote(userName) {
  return {
    type: _constants2.default.RECEIVE_PROMOTE_USER,
    data: {
      userName: userName
    }
  };
};

var invalidPromote = function invalidPromote() {
  return {
    type: _constants2.default.INVALID_PROMOTE_USER
  };
};

var shouldPromote = exports.shouldPromote = function shouldPromote(userName) {
  return function (dispatch) {
    dispatch(requestPromote(userName));

    return (0, _data.promote)(userName).then(function () {
      return dispatch(receivePromote(userName));
    }).catch((0, _actions.unauthorized)(dispatch, invalidPromote));
  };
};

var requestDemote = function requestDemote(userName) {
  return {
    type: _constants2.default.REQUEST_DEMOTE_USER,
    data: {
      userName: userName
    }
  };
};

var receiveDemote = function receiveDemote(userName) {
  return {
    type: _constants2.default.RECEIVE_DEMOTE_USER,
    data: {
      userName: userName
    }
  };
};

var invalidDemote = function invalidDemote() {
  return {
    type: _constants2.default.INVALID_DEMOTE_USER
  };
};

var shouldDemote = exports.shouldDemote = function shouldDemote(userName) {
  return function (dispatch) {
    dispatch(requestDemote(userName));

    return (0, _data.demote)(userName).then(function () {
      return dispatch(receiveDemote(userName));
    }).catch((0, _actions.unauthorized)(dispatch, invalidDemote));
  };
};

var requestBlock = function requestBlock(userName) {
  return {
    type: _constants2.default.REQUEST_BLOCK,
    data: {
      userName: userName
    }
  };
};

var receiveBlock = function receiveBlock(userName) {
  return {
    type: _constants2.default.RECEIVE_BLOCK,
    data: {
      userName: userName
    }
  };
};

var invalidBlock = function invalidBlock() {
  return {
    type: _constants2.default.INVALID_BLOCK
  };
};

var shouldBlock = exports.shouldBlock = function shouldBlock(userName) {
  return function (dispatch) {
    dispatch(requestBlock(userName));

    return (0, _data.block)(userName).then(function () {
      return dispatch(receiveBlock(userName));
    }).catch((0, _actions.unauthorized)(dispatch, invalidBlock));
  };
};

var requestUnBlock = function requestUnBlock(userName) {
  return {
    type: _constants2.default.REQUEST_UNBLOCK,
    data: {
      userName: userName
    }
  };
};

var receiveUnBlock = function receiveUnBlock(userName) {
  return {
    type: _constants2.default.RECEIVE_UNBLOCK,
    data: {
      userName: userName
    }
  };
};

var invalidUnBlock = function invalidUnBlock() {
  return {
    type: _constants2.default.INVALID_UNBLOCK
  };
};

var shouldUnBlock = exports.shouldUnBlock = function shouldUnBlock(userName) {
  return function (dispatch) {
    dispatch(requestUnBlock(userName));

    return (0, _data.unblock)(userName).then(function () {
      return dispatch(receiveUnBlock(userName));
    }).catch((0, _actions.unauthorized)(dispatch, invalidUnBlock));
  };
};

var requestFindIfUserExist = function requestFindIfUserExist() {
  return {
    type: _constants2.default.REQUEST_FIND_IF_USER_EXIST
  };
};

var receiveFindIfUserExist = function receiveFindIfUserExist(userName, result) {
  return {
    type: _constants2.default.RECEIVE_FIND_IF_USER_EXIST,
    data: {
      userName: userName,
      isExisting: result ? result.isAvailable : true
    }
  };
};

var invalidFindIfUserExist = function invalidFindIfUserExist() {
  return {
    type: _constants2.default.INVALID_FIND_IF_USER_EXIST
  };
};

var shouldFindIfUserExist = exports.shouldFindIfUserExist = function shouldFindIfUserExist(userName) {
  return function (dispatch) {
    dispatch(requestFindIfUserExist(userName));

    return (0, _data.isUserExisting)(userName).then(function (result) {
      return dispatch(receiveFindIfUserExist(userName, result));
    }).catch((0, _actions.unauthorized)(dispatch, invalidFindIfUserExist));
  };
};

var requestFindIfEmailExist = function requestFindIfEmailExist(email) {
  return {
    type: _constants2.default.REQUEST_FIND_IF_EMAIL_EXIST,
    data: {
      email: email
    }
  };
};

var receiveFindIfEmailExist = function receiveFindIfEmailExist(email, result) {
  return {
    type: _constants2.default.RECEIVE_FIND_IF_EMAIL_EXIST,
    data: {
      email: email,
      isExisting: result ? result.isAvailable : true
    }
  };
};

var invalidFindIfEmailExist = function invalidFindIfEmailExist() {
  return {
    type: _constants2.default.INVALID_FIND_IF_EMAIL_EXIST
  };
};

var shouldFindIfEmailExist = exports.shouldFindIfEmailExist = function shouldFindIfEmailExist(email) {
  return function (dispatch) {
    dispatch(requestFindIfEmailExist(email));

    return (0, _data.isEmailExisting)(email).then(function (result) {
      return dispatch(receiveFindIfEmailExist(email, result));
    }).catch((0, _actions.unauthorized)(dispatch, invalidFindIfEmailExist));
  };
};

var requestPotentialUsers = function requestPotentialUsers() {
  return {
    type: _constants2.default.REQUEST_POTENTIAL_USERS
  };
};

var receivePotentialUsers = function receivePotentialUsers(potentialUsers) {
  return {
    type: _constants2.default.RECEIVE_POTENTIAL_USERS,
    data: potentialUsers
  };
};

var invalidPotentialUsers = function invalidPotentialUsers() {
  return {
    type: _constants2.default.INVALID_POTENTIAL_USERS
  };
};

var fetchPotentialUsers = function fetchPotentialUsers() {
  return function (dispatch) {
    dispatch(requestPotentialUsers());

    return (0, _data.getPotentialUsers)().then(function (users) {
      dispatch(receivePotentialUsers(users));
    }).catch((0, _actions.unauthorized)(dispatch, invalidPotentialUsers));
  };
};

var shouldFetchPotentialUsers = function shouldFetchPotentialUsers(state) {
  return !(state[_reducers.storeName].potentialUsers && state[_reducers.storeName].potentialUsers.length > 0);
};

function fetchPotentialUsersIfNeeded() {
  return function (dispatch, getState) {
    if (shouldFetchPotentialUsers(getState())) {
      dispatch(fetchPotentialUsers());
    }
  };
}

var requestCurrentUser = function requestCurrentUser() {
  return {
    type: _constants2.default.REQUEST_CURRENT_USER
  };
};

var receiveCurrentUser = function receiveCurrentUser(user) {
  return {
    type: _constants2.default.RECEIVE_CURRENT_USER,
    data: {
      user: user
    }
  };
};

var invalidCurrentUser = function invalidCurrentUser() {
  return {
    type: _constants2.default.INVALID_CURRENT_USER
  };
};

var fetchCurrentUser = function fetchCurrentUser() {
  return function (dispatch, getState) {
    if (getState()[_reducers.storeName].currentUser) {
      return;
    }

    if (getState()[_reducers.storeName].isFetchingCurrentUser) {
      return;
    }

    dispatch(requestCurrentUser());

    return (0, _data.getCurrentUser)().then(function (user) {
      (0, _data.getUserProfile)(user.client.Id).then(function (userProfile) {
        user.userProfile = userProfile;
        dispatch(receiveCurrentUser(user));
      }).catch(function () {
        user.userProfile = void 0;
        dispatch(receiveCurrentUser(user));
      });
    }).catch((0, _actions.unauthorized)(dispatch, invalidCurrentUser));
  };
};

function shouldFetchCurrentUser() {
  return function (dispatch) {
    dispatch(fetchCurrentUser());
  };
}

var requestOpenInviteUserDialog = function requestOpenInviteUserDialog(email, name) {
  return {
    type: _constants2.default.REQUEST_OPEN_INVITE_USER_DIALOG,
    data: {
      email: email,
      name: name
    }
  };
};

var shouldOpenInviteUserDialog = exports.shouldOpenInviteUserDialog = function shouldOpenInviteUserDialog(email, name) {
  return function (dispatch, getState) {
    if (!getState()[_reducers.storeName].isOpenInviteUserDialog) {
      dispatch(requestOpenInviteUserDialog(email, name));
    }
  };
};

var requestCloseInviteUserDialog = function requestCloseInviteUserDialog() {
  return {
    type: _constants2.default.REQUEST_CLOSE_INVITE_USER_DIALOG
  };
};

var shouldCloseInviteUserDialog = exports.shouldCloseInviteUserDialog = function shouldCloseInviteUserDialog() {
  return function (dispatch) {
    dispatch(requestCloseInviteUserDialog());
  };
};

var shouldShowEmailIsAlreadyTaken = exports.shouldShowEmailIsAlreadyTaken = function shouldShowEmailIsAlreadyTaken(email) {
  return {
    type: _constants2.default.RECEIVE_EMAIL_IS_ALREADY_TAKEN,
    data: {
      email: email
    }
  };
};

function checkIfEmailExistAndSendInvitation(invitation) {

  return function (dispatch, getState) {

    return dispatch(shouldFindIfEmailExist(invitation.email)).then(function () {

      var isExisting = getState()[_reducers.storeName].isEmailExisting.isExisting;

      if (!isExisting) {
        return dispatch(shouldInviteUser(invitation));
      } else {
        return dispatch(shouldShowEmailIsAlreadyTaken(invitation.email));
      }
    });
  };
}

var requestAllInvitations = function requestAllInvitations() {
  return {
    type: _constants2.default.REQUEST_ALL_INVITATIONS
  };
};

var receiveAllInvitations = function receiveAllInvitations(invitations) {
  return {
    type: _constants2.default.RECEIVE_ALL_INVITATIONS,
    data: {
      invitations: invitations
    }
  };
};

var invalidAllInvitations = function invalidAllInvitations() {
  return {
    type: _constants2.default.INVALID_ALL_INVITATIONS
  };
};

function shouldFetchInvitations() {
  return function (dispatch) {
    dispatch(requestAllInvitations());

    return (0, _data.getInvitations)().then(function (invitations) {
      return dispatch(receiveAllInvitations(invitations));
    }).catch((0, _actions.unauthorized)(dispatch, invalidAllInvitations));
  };
};

var requestRemoveInvitation = function requestRemoveInvitation(invitation) {
  return {
    type: _constants2.default.REQUEST_REMOVE_INVITATION,
    data: {
      invitation: invitation
    }
  };
};

var receiveRemoveInvitation = function receiveRemoveInvitation(invitation) {
  return {
    type: _constants2.default.RECEIVE_REMOVE_INVITATION,
    data: {
      invitation: invitation
    }
  };
};

var invalidRemoveInvitation = function invalidRemoveInvitation(invitation) {
  return {
    type: _constants2.default.INVALID_REMOVE_INVITATION,
    data: { invitation: invitation }
  };
};

function shouldRemoveInvitation(invitation) {
  return function (dispatch) {
    dispatch(requestRemoveInvitation(invitation));

    return (0, _data.removeInvitation)(invitation).then(function () {
      return dispatch(receiveRemoveInvitation(invitation));
    }).catch(function (err) {
      (0, _logger.logException)(err);
      dispatch(invalidRemoveInvitation(invitation));
    });
  };
};

var requestRealTimePromoteInformation = function requestRealTimePromoteInformation(promoteNotification) {
  return {
    type: _constants2.default.RECEIVE_PROMOTE_INFORMATION,
    data: {
      promoteNotification: promoteNotification
    }
  };
};

function receiveRealTimePromoteInformation(promoteNotification) {
  return function (dispatch) {
    setTimeout(function () {
      dispatch(resetPromoteUserInformation(promoteNotification));
    }, 10000);
    dispatch(requestRealTimePromoteInformation(promoteNotification));
  };
};

var requestResetPromoteUserInformation = function requestResetPromoteUserInformation(promoteUserNotifications) {
  return {
    type: _constants2.default.RESET_PROMOTE_INFORMATION,
    data: {
      promoteUserNotifications: promoteUserNotifications
    }
  };
};

function resetPromoteUserInformation(promoteUserNotifications) {
  return function (dispatch) {
    dispatch(requestResetPromoteUserInformation(promoteUserNotifications));
  };
}

var requestRealTimeDemoteInformation = function requestRealTimeDemoteInformation(demoteNotification) {
  return {
    type: _constants2.default.RECEIVE_DEMOTE_INFORMATION,
    data: {
      demoteNotification: demoteNotification
    }
  };
};

function receiveRealTimeDemoteInformation(demoteNotification) {
  return function (dispatch) {
    setTimeout(function () {
      dispatch(resetDemoteUserInformation(demoteNotification));
    }, 10000);
    dispatch(requestRealTimeDemoteInformation(demoteNotification));
  };
};

var requestResetDemoteUserInformation = function requestResetDemoteUserInformation(demoteNotification) {
  return {
    type: _constants2.default.RESET_DEMOTE_INFORMATION,
    data: {
      demoteNotification: demoteNotification
    }
  };
};

function resetDemoteUserInformation(demoteNotification) {
  return function (dispatch) {
    dispatch(requestResetDemoteUserInformation(demoteNotification));
  };
}

var requestChangePassword = function requestChangePassword() {
  return {
    type: _constants2.default.REQUEST_CHANGE_PASSWORD
  };
};

var receiveChangePassword = function receiveChangePassword() {
  return {
    type: _constants2.default.RECEIVE_CHANGE_PASSWORD
  };
};

var invalidChangePassword = function invalidChangePassword() {
  return {
    type: _constants2.default.INVALID_CHANGE_PASSWORD
  };
};

var resetChangePassword = function resetChangePassword() {
  return {
    type: _constants2.default.RESET_CHANGE_PASSWORD
  };
};

function shouldChangePassword(passwordObject) {
  return function (dispatch) {
    dispatch(requestChangePassword(passwordObject));

    return (0, _data.changePassword)(passwordObject).then(function () {
      dispatch(receiveChangePassword(passwordObject));
      setTimeout(function () {
        dispatch(resetChangePassword());
      }, 10000);
    }).catch(function () {
      dispatch(invalidChangePassword());
    });
  };
}

var requestRealTimeInviteUserInformation = function requestRealTimeInviteUserInformation(invitation) {
  return {
    type: _constants2.default.REQUEST_NEW_USER_INVITED_INFORMATION,
    data: {
      invitation: invitation
    }
  };
};

function receiveRealTimeInvitedUserInformation(invitation) {
  return function (dispatch) {
    dispatch(requestRealTimeInviteUserInformation(invitation));
  };
};

var resetRealTimeInviteUserInformation = exports.resetRealTimeInviteUserInformation = function resetRealTimeInviteUserInformation(invitation) {
  return {
    type: _constants2.default.RESET_NEW_USER_INVITED_INFORMATION,
    data: {
      invitation: invitation
    }
  };
};

var requestRemoveOnBoarding = function requestRemoveOnBoarding() {
  return {
    type: _constants2.default.REQUEST_REMOVE_ON_BOADING
  };
};

var receiveRemoveOnBoarding = function receiveRemoveOnBoarding() {
  return {
    type: _constants2.default.RECEIVE_REMOVE_ON_BOARDING
  };
};

var invalidRemoveOnBoarding = function invalidRemoveOnBoarding() {
  return {
    type: _constants2.default.INVALID_REMOVE_ON_BOARDING
  };
};

var removeOnBoarding = exports.removeOnBoarding = function removeOnBoarding(userId, userProfile) {
  var userProfileToSave = userProfile;

  return function (dispatch) {
    dispatch(requestRemoveOnBoarding());

    if (!userProfileToSave) {
      userProfileToSave = {
        isOnBoardingFinished: true,
        userId: userId
      };
    } else {
      userProfileToSave.isOnBoardingFinished = true;
    }

    (0, _data.saveProfile)(userId, userProfileToSave).then(function () {
      _jsCookie2.default.set('isBoardingFinishedCached', true);
      dispatch(receiveRemoveOnBoarding());
    }).catch((0, _actions.unauthorized)(dispatch, invalidRemoveOnBoarding));
  };
};

var requestAddWidgetConfigurationToUserProfile = function requestAddWidgetConfigurationToUserProfile(widgetToAdd) {
  return {
    type: _constants2.default.REQUEST_ADD_WIDGET_CONFIGURATION_TO_USER_PROFILE,
    widgetToAdd: widgetToAdd
  };
};

var receiveAddWidgetConfigurationToUserProfile = function receiveAddWidgetConfigurationToUserProfile(widgetToAdd) {
  return {
    type: _constants2.default.RECEIVE_ADD_WIDGET_CONFIGURATION_TO_USER_PROFILE,
    data: {
      widgetToAdd: widgetToAdd
    }
  };
};

var invalidAddWidgetConfigurationToUserProfile = exports.invalidAddWidgetConfigurationToUserProfile = function invalidAddWidgetConfigurationToUserProfile() {
  return {
    type: _constants2.default.INVALID_ADD_WIDGET_CONFIGURATION_TO_USER_PROFILE
  };
};

var addWidgetConfigurationToUserProfile = exports.addWidgetConfigurationToUserProfile = function addWidgetConfigurationToUserProfile(widgetToAdd) {
  return function (dispatch, getState) {
    var userId = getState().user.currentUser.client.Id;

    dispatch(requestAddWidgetConfigurationToUserProfile(widgetToAdd));

    (0, _data.addWidthConfigToUserProfile)(userId, widgetToAdd).then(function () {

      dispatch(receiveAddWidgetConfigurationToUserProfile(widgetToAdd));
    }).catch((0, _actions.unauthorized)(dispatch, invalidAddWidgetConfigurationToUserProfile));
  };
};

var requestRemoveWidgetToUserProfile = function requestRemoveWidgetToUserProfile() {
  return {
    type: _constants2.default.REQUEST_REMOVE_WIDGET_TO_USER_PROFILE
  };
};

var invalidRemoveWidgetToUserProfile = function invalidRemoveWidgetToUserProfile() {
  return {
    type: _constants2.default.INVALID_REMOVE_WIDGET_TO_USER_PROFILE
  };
};

var receiveRemoveWidgetToUserProfile = function receiveRemoveWidgetToUserProfile(widgetToRemove) {
  return {
    type: _constants2.default.RECEIVE_REMOVE_WIDGET_TO_USER_PROFILE,
    data: {
      widgetToRemove: widgetToRemove
    }
  };
};

var shouldRemoveWidgetToUserProfile = exports.shouldRemoveWidgetToUserProfile = function shouldRemoveWidgetToUserProfile(widgetToRemove) {
  return function (dispatch, getState) {
    var userId = getState().user.currentUser.client.Id;
    dispatch(requestRemoveWidgetToUserProfile(widgetToRemove));

    (0, _data.removeWidgetToUserProfile)(userId, widgetToRemove).then(function () {
      dispatch(receiveRemoveWidgetToUserProfile(widgetToRemove));
    }).catch((0, _actions.unauthorized)(dispatch, invalidRemoveWidgetToUserProfile));
  };
};