'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.saveProfile = exports.changePassword = exports.getUserProfile = exports.getInvitations = exports.isEmailExisting = exports.isUserExisting = exports.unblock = exports.block = exports.demote = exports.promote = exports.removeInvitation = exports.resendInvitation = exports.inviteUser = exports.getAllUsers = undefined;
exports.getPotentialUsers = getPotentialUsers;
exports.getCurrentUser = getCurrentUser;
exports.addWidthConfigToUserProfile = addWidthConfigToUserProfile;
exports.removeWidgetToUserProfile = removeWidgetToUserProfile;

var _request = require('cluedin-core/request');

var _fromServer = require('cluedin-core/fromServer');

var _entity = require('cluedin-core/iso/entity');

var _entity2 = _interopRequireDefault(_entity);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var toVM = _entity2.default.toVM;

var getAllUsers = exports.getAllUsers = function getAllUsers() {
  return (0, _request.apiRequest)('GET', 'api/account/accounts').then(function (resp) {
    resp.body.forEach(function (u) {
      if (u.Entity) {
        u.Entity = toVM(u.Entity, (0, _fromServer.getCurrentToken)(), true);
      }
    });

    return resp.body;
  });
};

function getPotentialUsers() {
  return (0, _request.apiRequest)('GET', 'api/entity/domainusers').then(function (resp) {
    return resp.body;
  });
}

function getCurrentUser() {
  return (0, _request.apiRequest)('GET', 'api/account/user').then(function (resp) {
    var user = resp.body;
    user.entity = toVM(user.entity, (0, _fromServer.getCurrentToken)(), true);

    return user;
  });
}

var inviteUser = exports.inviteUser = function inviteUser(invitation) {
  /*
   * {
   email: $scope.email,
   orgName: $scope.orgName,
   userName: $scope.userName,
   isAdmin: $scope.admin.isAdmin
   }
   * */
  return (0, _request.frontApiRequest)('POST', 'account/invitation', { invite: invitation });
};

var resendInvitation = exports.resendInvitation = function resendInvitation(invitation) {
  return (0, _request.frontApiRequest)('POST', 'account/invitation', { invite: invitation });
};

var removeInvitation = exports.removeInvitation = function removeInvitation(invite) {
  return (0, _request.frontApiRequest)('POST', 'account/removeinvitation', { invite: invite });
};

var promote = exports.promote = function promote(userName) {
  return (0, _request.apiRequest)('PUT', 'api/account/setadmin?username=' + userName + '&value=' + true);
};

var demote = exports.demote = function demote(userName) {
  return (0, _request.apiRequest)('PUT', 'api/account/setadmin?username=' + userName + '&value=' + false);
};

var block = exports.block = function block(userName) {
  return (0, _request.apiRequest)('PUT', 'api/account/block?username=' + userName + '&value=' + true);
};

var unblock = exports.unblock = function unblock(userName) {
  return (0, _request.apiRequest)('PUT', 'api/account/block?username=' + userName + '&value=' + false);
};

var isUserExisting = exports.isUserExisting = function isUserExisting(userName) {
  return (0, _request.apiRequest)('GET', 'api/account/username?username=' + userName).then(function (resp) {
    return resp.body;
  });
};

var isEmailExisting = exports.isEmailExisting = function isEmailExisting(email) {
  return (0, _request.apiRequest)('GET', 'api/account/emailavailable?email=' + email).then(function (resp) {
    return resp.body;
  });
};

var getInvitations = exports.getInvitations = function getInvitations() {
  return (0, _request.frontApiRequest)('GET', 'api/users/invites').then(function (resp) {
    return resp.body;
  });
};

var getUserProfile = exports.getUserProfile = function getUserProfile(id) {
  return (0, _request.frontApiRequest)('GET', 'profileuser/' + id + '/' + _fromServer.clientId).then(function (resp) {
    var userProfile = resp.body;

    if (userProfile && userProfile.widgetConfiguration && userProfile.widgetConfiguration.length > 0) {
      userProfile.widgetConfiguration.forEach(function (widgetConfig) {
        if (widgetConfig.widgets && widgetConfig.widgets.length > 0) {
          widgetConfig.widgets.forEach(function (w) {
            if (w.parameters) {
              try {
                w.parameters = JSON.parse(w.parameters);
              } catch (e) {
                console.log('something went wrong');
              }
            }
          });
        }
      });
    }

    return userProfile;
  });
};

var changePassword = exports.changePassword = function changePassword(data) {
  return (0, _request.authRequest)('POST', 'api/account/change', data);
};

var saveProfile = exports.saveProfile = function saveProfile(id, userProfile) {
  return (0, _request.frontApiRequest)('POST', 'profileuser/' + id).send(userProfile).then(function (resp) {
    return resp.body;
  });
};

function addWidthConfigToUserProfile(userId, widgetToAdd) {
  return (0, _request.frontApiRequest)('POST', 'api/userprofile/widget/' + userId, widgetToAdd).then(function (resp) {
    return resp.body;
  });
};

function removeWidgetToUserProfile(userId, widgetToRemove) {
  return (0, _request.frontApiRequest)('POST', 'api/userprofile/removewidget/' + userId, widgetToRemove).then(function (resp) {
    return resp.body;
  });
};