'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.reducer = exports.storeName = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _simpleAssign = require('simple-assign');

var _simpleAssign2 = _interopRequireDefault(_simpleAssign);

var _constants = require('../constants');

var _constants2 = _interopRequireDefault(_constants);

var _jsCookie = require('js-cookie');

var _jsCookie2 = _interopRequireDefault(_jsCookie);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isBoardingFinished = !!_jsCookie2.default.get('isBoardingFinishedCached');

var initialState = {
  allUsers: [],
  isFetchingAllUsers: false,
  inviteUsers: {},
  sendInvitations: {},
  promoteUsers: {},
  demoteUsers: {},
  blockUsers: {},
  unBlockUsers: {},
  isUserExisting: {},
  isEmailExisting: {},
  potentialUsers: [],
  isFetchingPotentialUsers: false,
  currentUser: void 0,
  isFetchingCurrentUser: false,
  isOpenInviteUserDialog: false,
  emailAlreadyTakenForInviteUsers: void 0,
  inviteUserSomethingIsWrong: false,
  allInvitations: [],
  isFetchingAllInvitations: false,
  removeInvitations: {},
  promoteUserNotifications: [],
  demoteUserNotifications: [],
  isChangingPassword: false,
  isChangingPasswordSucceed: false,
  isChangingPasswordError: false,
  newInviteUserNotifications: [],
  isBoardingFinishedCached: isBoardingFinished
};

var storeName = exports.storeName = 'user';

var reducer = exports.reducer = function update() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  switch (action.type) {
    case _constants2.default.REQUEST_CURRENT_USER:
      return (0, _simpleAssign2.default)({}, state, {
        isFetchingCurrentUser: true
      });
    case _constants2.default.RECEIVE_CURRENT_USER:
      return (0, _simpleAssign2.default)({}, state, {
        currentUser: action.data.user,
        isFetchingCurrentUser: false
      });
    case _constants2.default.REQUEST_ALL_USERS:
      return (0, _simpleAssign2.default)({}, state, {
        isFetchingAllUsers: true
      });
    case _constants2.default.RECEIVE_ALL_USERS:
      return (0, _simpleAssign2.default)({}, state, {
        allUsers: [].concat((0, _toConsumableArray3.default)(action.data.users)),
        isFetchingAllUsers: false
      });
    case _constants2.default.REQUEST_INVITE_USER:
      var newRequestInviteUsers = state.inviteUsers;

      newRequestInviteUsers[action.data.invitation.email] = {
        email: action.data.invitation.email,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        inviteUsers: (0, _simpleAssign2.default)({}, newRequestInviteUsers),
        inviteUserSomethingIsWrong: false
      });
    case _constants2.default.RECEIVE_INVITE_USER:
      var newReceiveInviteUsers = state.inviteUsers;

      newReceiveInviteUsers[action.data.invitation.email] = {
        email: action.data.invitation.email,
        isFetching: false,
        emailAlreadyTakenForInviteUsers: '',
        inviteUserSomethingIsWrong: false
      };

      return (0, _simpleAssign2.default)({}, state, {
        inviteUsers: (0, _simpleAssign2.default)({}, newReceiveInviteUsers),
        isOpenInviteUserDialog: false
      });
    case _constants2.default.INVALID_INVITE_USER:
      return (0, _simpleAssign2.default)({}, state, {
        inviteUserSomethingIsWrong: true
      });

    case _constants2.default.INVALID_RESEND_INVITATION:
      var newRequestInvalidResendInvitations = state.sendInvitations;

      newRequestInvalidResendInvitations[action.data.invitation.email] = {
        email: action.data.invitation.email,
        hasError: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        sendInvitations: (0, _simpleAssign2.default)({}, newRequestInvalidResendInvitations)
      });
    case _constants2.default.REQUEST_RESEND_INVITATION:
      var newRequestInvitations = state.sendInvitations;

      newRequestInvitations[action.data.invitation.email] = {
        email: action.data.invitation.email,
        isFetching: true,
        hasError: false
      };

      return (0, _simpleAssign2.default)({}, state, {
        sendInvitations: (0, _simpleAssign2.default)({}, newRequestInvitations)
      });
    case _constants2.default.RECEIVE_RESEND_INVITATION:
      var newReceiveInvitations = state.sendInvitations;

      newReceiveInvitations[action.data.invitation.email].isFetching = false;

      return (0, _simpleAssign2.default)({}, state, {
        sendInvitations: (0, _simpleAssign2.default)({}, newReceiveInvitations)
      });
    case _constants2.default.REQUEST_PROMOTE_USER:
      var requestPromoteUsers = state.promoteUsers;

      requestPromoteUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        promoteUsers: (0, _simpleAssign2.default)({}, requestPromoteUsers)
      });
    case _constants2.default.RECEIVE_PROMOTE_USER:
      var receivePromoteUsers = state.promoteUsers;
      var currentPromoteUser = state.allUsers.find(function (u) {
        return u.Account.UserName === action.data.userName;
      });

      currentPromoteUser.Account.IsAdmin = true;

      receivePromoteUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: false
      };

      return (0, _simpleAssign2.default)({}, state, {
        allUsers: [].concat((0, _toConsumableArray3.default)(state.allUsers)),
        promoteUsers: (0, _simpleAssign2.default)({}, receivePromoteUsers)
      });
    case _constants2.default.REQUEST_DEMOTE_USER:
      var requestDemoteUsers = state.demoteUsers;

      requestDemoteUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        demoteUsers: (0, _simpleAssign2.default)({}, requestDemoteUsers)
      });
    case _constants2.default.RECEIVE_DEMOTE_USER:
      var receiveDemoteUsers = state.demoteUsers;
      var currentDemoteUser = state.allUsers.find(function (u) {
        return u.Account.UserName === action.data.userName;
      });

      currentDemoteUser.Account.IsAdmin = false;

      receiveDemoteUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: false
      };

      return (0, _simpleAssign2.default)({}, state, {
        allUsers: [].concat((0, _toConsumableArray3.default)(state.allUsers)),
        demoteUsers: (0, _simpleAssign2.default)({}, receiveDemoteUsers)
      });
    case _constants2.default.REQUEST_BLOCK:
      var requestBlockUsers = state.blockUsers;

      requestBlockUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        blockUsers: (0, _simpleAssign2.default)({}, requestBlockUsers)
      });
    case _constants2.default.RECEIVE_BLOCK:
      var receiveBlockUsers = state.blockUsers;
      var currentBlockUser = state.allUsers.find(function (u) {
        return u.Account.UserName === action.data.userName;
      });

      currentBlockUser.Account.LockoutEnabled = true;

      receiveBlockUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: false
      };

      return (0, _simpleAssign2.default)({}, state, {
        allUsers: [].concat((0, _toConsumableArray3.default)(state.allUsers)),
        blockUsers: (0, _simpleAssign2.default)({}, receiveBlockUsers)
      });
    case _constants2.default.REQUEST_UNBLOCK:
      var requestUnBlockUsers = state.unBlockUsers;

      requestUnBlockUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        unBlockUsers: (0, _simpleAssign2.default)({}, requestUnBlockUsers)
      });
    case _constants2.default.RECEIVE_UNBLOCK:
      var receiveUnBlockUsers = state.unBlockUsers;
      var currentUnBlockUser = state.allUsers.find(function (u) {
        return u.Account.UserName === action.data.userName;
      });

      currentUnBlockUser.Account.LockoutEnabled = false;

      receiveUnBlockUsers[action.data.userName] = {
        userName: action.data.userName,
        isFetching: false
      };

      return (0, _simpleAssign2.default)({}, state, {
        allUsers: [].concat((0, _toConsumableArray3.default)(state.allUsers)),
        unBlockUsers: (0, _simpleAssign2.default)({}, receiveUnBlockUsers)
      });
    case _constants2.default.REQUEST_FIND_IF_USER_EXIST:
      var requestIsUserExisting = state.isUserExisting;

      requestIsUserExisting[action.data.userName] = {
        userName: action.data.userName,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        isUserExisting: (0, _simpleAssign2.default)({}, requestIsUserExisting)
      });
    case _constants2.default.RECEIVE_FIND_IF_USER_EXIST:
      var receiveIsUserExisting = state.isUserExisting;

      receiveIsUserExisting[action.data.userName].isExisting = action.data.isExisting;

      return (0, _simpleAssign2.default)({}, state, {
        isUserExisting: (0, _simpleAssign2.default)({}, receiveIsUserExisting)
      });
    case _constants2.default.REQUEST_FIND_IF_EMAIL_EXIST:
      var requestIsEmailExisting = state.isEmailExisting;

      requestIsEmailExisting[action.data.email] = {
        email: action.data.email,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        isEmailExisting: (0, _simpleAssign2.default)({}, requestIsEmailExisting)
      });
    case _constants2.default.RECEIVE_FIND_IF_EMAIL_EXIST:
      var receiveIsEmailExisting = state.isEmailExisting;

      receiveIsEmailExisting[action.data.email].isExisting = action.data.isExisting;

      return (0, _simpleAssign2.default)({}, state, {
        isEmailExisting: (0, _simpleAssign2.default)({}, receiveIsEmailExisting)
      });
    case _constants2.default.REQUEST_POTENTIAL_USERS:
      return (0, _simpleAssign2.default)({}, state, {
        potentialUsers: [],
        isFetchingPotentialUsers: true
      });
    case _constants2.default.INVALID_POTENTIAL_USERS:
      return (0, _simpleAssign2.default)({}, state, {
        isFetchingPotentialUsers: false
      });
    case _constants2.default.RECEIVE_POTENTIAL_USERS:
      return (0, _simpleAssign2.default)({}, state, {
        potentialUsers: action.data,
        isFetchingPotentialUsers: false
      });
    case _constants2.default.REQUEST_OPEN_INVITE_USER_DIALOG:
      return (0, _simpleAssign2.default)({}, state, {
        isOpenInviteUserDialog: true,
        inviteUserFeedValueEmail: action.data.email,
        inviteUserFeedValueName: action.data.name
      });
    case _constants2.default.REQUEST_CLOSE_INVITE_USER_DIALOG:
      return (0, _simpleAssign2.default)({}, state, {
        isOpenInviteUserDialog: false,
        inviteUsers: {},
        inviteUserSomethingIsWrong: false,
        emailAlreadyTakenForInviteUsers: ''
      });
    case _constants2.default.RECEIVE_EMAIL_IS_ALREADY_TAKEN:
      return (0, _simpleAssign2.default)({}, state, {
        emailAlreadyTakenForInviteUsers: action.data.email
      });
    case _constants2.default.REQUEST_REMOVE_INVITATION:
      var newRequestRemoveInvitations = state.removeInvitations;

      newRequestRemoveInvitations[action.data.invitation.email] = {
        email: action.data.invitation.email,
        isFetching: true
      };

      return (0, _simpleAssign2.default)({}, state, {
        removeInvitations: (0, _simpleAssign2.default)({}, newRequestRemoveInvitations)
      });
    case _constants2.default.INVALID_REMOVE_INVITATION:
      var newReceiveFailedRemoveInvitations = state.removeInvitations;
      newReceiveFailedRemoveInvitations[action.data.invitation.email] = {
        email: action.data.invitation.email,
        isFetching: false,
        hasError: true
      };

      // TODO need an error

      return (0, _simpleAssign2.default)({}, state, {
        removeInvitations: (0, _simpleAssign2.default)({}, newReceiveFailedRemoveInvitations)
      });
    case _constants2.default.RECEIVE_REMOVE_INVITATION:
      var newReceiveRemoveInvitations = state.removeInvitations;

      newReceiveRemoveInvitations[action.data.invitation.email].isFetching = false;

      var newAllInvitations = state.allInvitations.map(function (i) {
        if (action.data.invitation.email === i.email) {
          return (0, _extends3.default)({}, i, {
            removed: true
          });
        }
        return i;
      });

      return (0, _simpleAssign2.default)({}, state, {
        removeInvitations: (0, _simpleAssign2.default)({}, newReceiveRemoveInvitations),
        allInvitations: newAllInvitations
      });
    case _constants2.default.REQUEST_ALL_INVITATIONS:
      return (0, _simpleAssign2.default)({}, state, {
        isFetchingAllInvitations: true
      });
    case _constants2.default.RECEIVE_ALL_INVITATIONS:
      return (0, _simpleAssign2.default)({}, state, {
        allInvitations: [].concat((0, _toConsumableArray3.default)(action.data.invitations)),
        isFetchingAllInvitations: false
      });
    case _constants2.default.REQUEST_NEW_USER_INVITED_INFORMATION:
      return (0, _simpleAssign2.default)({}, state, {
        newInviteUserNotifications: [].concat((0, _toConsumableArray3.default)(state.newInviteUserNotifications), [{
          invitation: action.data.invitation,
          show: true
        }])
      });
    case _constants2.default.RESET_NEW_USER_INVITED_INFORMATION:
      var invitationNotificationToUpdate = state.newInviteUserNotifications.filter(function (i) {
        return i.invitation.email === action.data.invitation.email;
      });

      invitationNotificationToUpdate.forEach(function (invitationNotification) {
        invitationNotification.show = false;
      });

      return (0, _simpleAssign2.default)({}, state, {
        newInviteUserNotifications: [].concat((0, _toConsumableArray3.default)(state.newInviteUserNotifications))
      });
    case _constants2.default.RECEIVE_PROMOTE_INFORMATION:
      return (0, _simpleAssign2.default)({}, state, {
        promoteUserNotifications: [].concat((0, _toConsumableArray3.default)(state.promoteUserNotifications), [{
          userName: action.data.promoteNotification.userName,
          authorUserName: action.data.promoteNotification.authorUserName,
          show: true
        }])
      });
    case _constants2.default.RESET_PROMOTE_INFORMATION:
      var toUpdate = state.promoteUserNotifications.filter(function (pUN) {
        return pUN.userName === action.data.promoteUserNotifications.userName && pUN.authorUserName === action.data.promoteUserNotifications.authorUserName;
      });

      toUpdate.forEach(function (promoteUserNotificationToUpdate) {
        promoteUserNotificationToUpdate.show = false;
      });

      return (0, _simpleAssign2.default)({}, state, {
        promoteUserNotifications: [].concat((0, _toConsumableArray3.default)(state.promoteUserNotifications))
      });
    case _constants2.default.RECEIVE_DEMOTE_INFORMATION:
      return (0, _simpleAssign2.default)({}, state, {
        demoteUserNotifications: [].concat((0, _toConsumableArray3.default)(state.demoteUserNotifications), [{
          userName: action.data.demoteNotification.userName,
          authorUserName: action.data.demoteNotification.authorUserName,
          show: true
        }])
      });
    case _constants2.default.RESET_DEMOTE_INFORMATION:
      var demotetoUpdate = state.demoteUserNotifications.filter(function (dUN) {
        return dUN.userName === action.data.demoteNotification.userName && dUN.authorUserName === action.data.demoteNotification.authorUserName;
      });

      demotetoUpdate.forEach(function (demoteUserNotificationToUpdate) {
        demoteUserNotificationToUpdate.show = false;
      });

      return (0, _simpleAssign2.default)({}, state, {
        demoteUserNotifications: [].concat((0, _toConsumableArray3.default)(demotetoUpdate))
      });
    case _constants2.default.REQUEST_CHANGE_PASSWORD:
      return (0, _simpleAssign2.default)({}, state, {
        isChangingPassword: true,
        isChangingPasswordSucceed: false,
        isChangingPasswordError: false
      });
    case _constants2.default.RECEIVE_CHANGE_PASSWORD:
      return (0, _simpleAssign2.default)({}, state, {
        isChangingPassword: false,
        isChangingPasswordSucceed: true,
        isChangingPasswordError: false
      });
    case _constants2.default.INVALID_CHANGE_PASSWORD:
      return (0, _simpleAssign2.default)({}, state, {
        isChangingPassword: false,
        isChangingPasswordSucceed: false,
        isChangingPasswordError: true
      });
    case _constants2.default.RESET_CHANGE_PASSWORD:
      return (0, _simpleAssign2.default)({}, state, {
        isChangingPassword: false,
        isChangingPasswordSucceed: false,
        isChangingPasswordError: false
      });
    case _constants2.default.RECEIVE_REMOVE_ON_BOARDING:
      var newCurrentUser = state.currentUser;

      newCurrentUser.userProfile.isOnBoardingFinished = true;

      return (0, _simpleAssign2.default)({}, state, {
        currentUser: (0, _simpleAssign2.default)({}, newCurrentUser),
        isBoardingFinishedCached: true
      });
    case _constants2.default.RECEIVE_REMOVE_WIDGET_TO_USER_PROFILE:
      var newCurrentUserForWidgetToRemove = state.currentUser;

      if (!newCurrentUserForWidgetToRemove.userProfile.widgetConfiguration) {
        newCurrentUserForWidgetToRemove.userProfile.widgetConfiguration = [{
          entityType: action.data.widgetToRemove.entityType,
          widgets: [{
            place: action.data.widgetToRemove.place,
            name: action.data.widgetToRemove.name,
            isDeleted: true
          }]
        }];
      } else {
        var hadConfigForWidget = newCurrentUserForWidgetToRemove.userProfile.widgetConfiguration.find(function (configPerType) {
          return configPerType.entityType.toLowerCase() === action.data.widgetToRemove.entityType.toLowerCase();
        });

        if (hadConfigForWidget) {
          hadConfigForWidget.widgets = hadConfigForWidget.widgets || [];

          hadConfigForWidget.widgets = hadConfigForWidget.widgets.filter(function (w) {
            return w.name.toLowerCase() !== action.data.widgetToRemove.name.toLowerCase();
          });

          hadConfigForWidget.widgets.push({
            place: action.data.widgetToRemove.place,
            name: action.data.widgetToRemove.name,
            isDeleted: true
          });
        } else {
          newCurrentUserForWidgetToRemove.userProfile.widgetConfiguration.push({
            entityType: action.data.widgetToRemove.entityType,
            widgets: [{
              place: action.data.widgetToRemove.place,
              name: action.data.widgetToRemove.name,
              isDeleted: true
            }]
          });
        }
      }

      return (0, _simpleAssign2.default)({}, state, {
        currentUser: (0, _simpleAssign2.default)({}, newCurrentUserForWidgetToRemove)
      });
    case _constants2.default.RECEIVE_ADD_WIDGET_CONFIGURATION_TO_USER_PROFILE:
      var newCurrentUserForWidgetToAdd = state.currentUser;

      if (!newCurrentUserForWidgetToAdd.userProfile.widgetConfiguration) {
        newCurrentUserForWidgetToAdd.userProfile.widgetConfiguration = [{
          entityType: action.data.widgetToAdd.entityType,
          widgets: [{
            place: action.data.widgetToAdd.place,
            name: action.data.widgetToAdd.name,
            parameters: action.data.widgetToAdd.values
          }]
        }];
      } else {
        var _hadConfigForWidget = newCurrentUserForWidgetToAdd.userProfile.widgetConfiguration.find(function (configPerType) {
          return configPerType.entityType.toLowerCase() === action.data.widgetToAdd.entityType.toLowerCase();
        });

        if (_hadConfigForWidget) {
          _hadConfigForWidget.widgets = _hadConfigForWidget.widgets || [];
          _hadConfigForWidget.widgets.push({
            place: action.data.widgetToAdd.place,
            name: action.data.widgetToAdd.name,
            parameters: action.data.widgetToAdd.values
          });
        } else {
          newCurrentUserForWidgetToAdd.userProfile.widgetConfiguration.push({
            entityType: action.data.widgetToAdd.entityType,
            widgets: [{
              place: action.data.widgetToAdd.place,
              name: action.data.widgetToAdd.name,
              parameters: action.data.widgetToAdd.values
            }]
          });
        }
      }

      return (0, _simpleAssign2.default)({}, state, {
        currentUser: (0, _simpleAssign2.default)({}, newCurrentUserForWidgetToAdd)
      });
    default:
      return state;
  }
};